; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; This source file was created using NBASM's Wizard software
; Forever Young Software
; 

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; General equates
;
TRUE       equ   0
FALSE      equ  -1

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
;  DISK

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; BIOS Parameter Block structure
;
STRUCT_BPB struct
bytessec   word       ; number of bytes per sector
secclust   byte       ; sectors per cluster
resvsect   word       ; number of reserved sectors
fats       byte       ; number of FATs
rootentry  word       ; number of entries in root directory
totsects   word       ; totol number of sectors (below v4.0)
mediaid    byte       ; media ID byte
sectfat    word       ; number of sectors per FAT
secttrack  word       ; number of sectors per track
heads      word       ; number of heads
hidden     dword      ; number of hidden sectors
totsectsl  dword      ; totol number of sectors (v4.0+)
resv1      dup    6   ;
cylinders  word       ; number of cylinders
devicetype byte       ; device type
deviceattr word       ; device attributes
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; Extended BIOS Parameter Block structure
;
STRUCT_EBPB struct
bytessec   word       ; number of bytes per sector
secclust   byte       ; sectors per cluster
resvsect   word       ; number of reserved sectors
fats       byte       ; number of FATs
rootentry  word       ; number of entries in root directory
totsects   word       ; totol number of sectors (below v4.0)
mediaid    byte       ; media ID byte
sectfat    word       ; number of sectors per FAT
secttrack  word       ; number of sectors per track
heads      word       ; number of heads
hidden     dword      ; number of hidden sectors
totsectsl  dword      ; totol number of sectors (v4.0+)
sectfatl   dword      ; sectors per FAT if 'sectfat' is 0000h
extflags   word       ; extended flags
fsversion  word       ; file system version
rootstart  dword      ; starting cluster number of root directory
fsinfosect word       ; file system information sector number
bootbak    word       ; sector number of backup boot sector
resv1      dup    6   ; reserved
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; diskette parameter table structure
;
STRUCT_DPT struct
specify1   byte       ; first specify byte
specify2   byte       ; second specify byte
delay      byte       ; delay until motor turned off (in clock ticks)
bytessect  byte       ; bytes per sector (00h = 128, 01h = 256, 02h = 512, 03h = 1024)
secttrack  byte       ; sectors per track
gaplen     byte       ; length of gap between sectors (2Ah for 5.25", 1Bh for 3.5")
datalen    byte       ; data length (ignored if bytes-per-sector field nonzero)
gaplenf    byte       ; gap length when formatting (50h for 5.25", 6Ch for 3.5")
filler     byte       ; format filler byte (default F6h)
settle     byte       ; head settle time in milliseconds
motorst    byte       ; motor start time in 1/8 seconds
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; diskette parameter table structure (IBM SurePath BIOS)
;
STRUCT_DPTS struct
specify1   byte       ; first specify byte
specify2   byte       ; second specify byte
delay      byte       ; delay until motor turned off (in clock ticks)
bytessect  byte       ; bytes per sector (00h = 128, 01h = 256, 02h = 512, 03h = 1024)
secttrack  byte       ; sectors per track
gaplen     byte       ; length of gap between sectors (2Ah for 5.25", 1Bh for 3.5")
datalen    byte       ; data length (ignored if bytes-per-sector field nonzero)
gaplenf    byte       ; gap length when formatting (50h for 5.25", 6Ch for 3.5")
filler     byte       ; format filler byte (default F6h)
settle     byte       ; head settle time in milliseconds
motorst    byte       ; motor start time in 1/8 seconds
maxtrack   byte       ; maximum track number
rate       byte       ; data transfer rate
type       byte       ; drive type in CMOS
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; hard disk master boot sector structure
;
STRUCT_MBS struct
bootstrap  dup  446   ; Master bootstrap loader code
partrec1   dup   16   ; partition record for partition 1
partrec2   dup   16   ; partition record for partition 2
partrec2   dup   16   ; partition record for partition 3
partrec3   dup   16   ; partition record for partition 4
signature  word       ; signature, AA55h indicates valid boot block
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; hard disk partition record structure
;
STRUCT_PART struct
bootid     byte       ; boot indicator (80h = active partition)
starthead  byte       ; partition start head
startsect  byte       ; partition start sector (bits 0-5)
starttrck  byte       ; partition start track (bits 8,9 in bits 6,7 of sector)
osid       byte       ; operating system indicator
endhead    byte       ; partition end head
endsect    byte       ; partition end sector (bits 0-5)
endtrack   byte       ; partition end track (bits 8,9 in bits 6,7 of sector)
preceding  dword      ; DWORD sectors preceding partition
partlen    dword      ; length of partition in sectors
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; disk info structure
;
STRUCT_DINF struct
infolevel  word       ; (info level)
serialnum  dword      ; disk serial number (binary)
volume     dup   11   ; volume label or "NO NAME    " if none present
filesys    dup    8   ; filesystem type
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
;  DOS

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; PSP structure
;
STRUCT_PSP struct
int20h     word
lastpara   word
resv1      byte
dosfuctn   dup    5
int22h     dword
int23h     dword
int24h     dword
paraseg    word
farray     dup   20
envseg     word
sssp       dword
farrsize   word
farrptr    dword
prevpsp    dword
resv2      dword
dosver     word
resv3      dup   14
int21retf  dup    3
resv4      dup    9
fcb1       dup   16
fcb2       dup   20
cmmndline  dup  128
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; command line structure
;
STRUCT_CMNDLINE struct
length     byte       ; length of comand line not counting trailing CR
line       dup  127   ; command line
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; EXEC parameter block structure (AL=00h,01h,04h)
;
STRUCT_EXEC0 struct
environ    word       ; segment of environment to copy for child process
pcomtail   dword      ; pointer to command tail to be copied into child's PSP
pfcb1      dword      ; pointer to first FCB to be copied into child's PSP
pfcb2      dword      ; pointer to second FCB to be copied into child's PSP
initsssp   dword      ; will hold subprogram's initial SS:SP on return
entrycsip  dword      ; will hold entry point (CS:IP) on return
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; EXEC parameter block structure (AL=03h)
;
STRUCT_EXEC3 struct
overlay    word       ; segment at which to load overlay
relofact   word       ; relocation factor to apply to overlay (.EXE format)
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; EXEC parameter block structure (FlashTek X-32)
;
STRUCT_EXECX struct
fpenviron  fword      ; 48-bit far pointer to environment string
fpcomtail  fword      ; 48-bit far pointer to command tail string
           ends

; =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
; Format of .EXE file header structure (DOS)
;
STRUCT_EXE struct
signature  word       ; .EXE signature, either "MZ" or "ZM" (5A4Dh or 4D5Ah)
lpagelen   word       ; number of bytes in last 512-byte page of executable
pages      word       ; total number of 512-byte pages in executable (includes any
relos      word       ; number of relocation entries
headsize   word       ; header size in paragraphs
minparas   word       ; minimum paragraphs of memory required to allocate
maxparas   word       ; maximum paragraphs to allocate in addition to executable's size
initss     word       ; initial SS relative to start of executable
initsp     word       ; initial SP
checksum   word       ; checksum (one's complement of sum of all words in executable)
initcsip   dword      ; initial CS:IP relative to start of executable
relooff    word       ; offset within header of relocation table
overlay    word       ; overlay number (normally 0000h = main program)
           ends



.end


DOS-internal data (see INT 21/AH=52h)
	Current Directory Structure (see #01643,#01644,#01645)
	Disk buffer (see #01649,#01650,#01652,#01653,#01655)
	DOS Parameter List (DPL) (see #01686 at INT 21/AX=5D00h)
	IFS entry point (see #01658)
	List of Lists (SYSVARS) (see #01627)
	Memory Control Block (see #01628,#01630,#01633)
	Swappable Data Area (SDA) (see #01687,#01690 at INT 21/AX=5D0Bh)
	System File Table (SFT) (see #01639,#01640,#01641,#01642)

Files and Directories
	Directory Entry: MS-DOS, DR DOS, Novell DOS (see #01352)
	file attributes (see #01401 at INT 21/AH=3Ch)
	File Control Block (FCB) (see #01345 at INT 21/AH=0Fh)
	File Date and Time (see #01665,#01666 at INT 21/AX=5700h)
	file-sharing behavior (see #01403 at INT 21/AH=3Dh)
	FindFirst data block (see #01626 at INT 21/AH=4Eh)
	Long File Names (see INT 21/AH=71h,#01355 at INT 21/AH=11h)

PCI Bus
	PCI BIOS error codes (see #00729 at INT 1A/AX=B101h)
	PCI configuration data (see #00878 at INT 1A/AX=B10Ah)
	PCI vendor ID (see #00732 at INT 1A/AX=B102h)
	PCI IRQ Routing Table (see #01259 at INT 1A/AX=B406h)

Plug-and-Play
	Plug-and-Play Installation Structure (see #F0024)
	Plug-and-Play error codes (see #F0081)
	Plug-and-Play device type codes (see #F0085)
	Extended System Configuration Data (ESCD)(see #01244 at INT 1A/AX=B401h)
	generic device IDs (see #F0086)

Real-Time Clock (see also CMOS.LST)
	status registers (see #00406,#00407,#00408 at INT 15/AH=01h"Amstrad")

Serial Port
	serial port parameters (see #00300 at INT 14/AH=00h)
	serial line status (see #00304 at INT 14/AH=03h)
	modem status (see #00305 at INT 14/AH=03h)

Video
	character attributes (see #00014 at INT 10/AH=08h)
	Display Combination Code (DCC) (see #00039 at INT 10/AX=1A00h)
	TopView/RSIS shadow buffer [virtual screen] (see INT 10/AH=FEh)
	VESA DDC monitor information (see #00127 at INT 10/AX=4F15h/BL=01h)
	VESA SuperVGA information (see #00077 at INT 10/AX=4F00h)
	video modes
		mode numbers (see #00010 at INT 10/AH=00h)
		UltraVision modes (see #00220 at INT 10/AX=CD04h)
		VESA modes (see #00083 at INT 10/AX=4F02h)
	video parameters (see #01263 at INT 1D)
